# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt

class RemoveTeamMemberRoleRequest(BaseModel):
    """
    RemoveTeamMemberRoleRequest
    """
    id: StrictInt = Field(...)
    replacement_role_id: Optional[StrictInt] = None
    __properties = ["id", "replacement_role_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RemoveTeamMemberRoleRequest:
        """Create an instance of RemoveTeamMemberRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if replacement_role_id (nullable) is None
        # and __fields_set__ contains the field
        if self.replacement_role_id is None and "replacement_role_id" in self.__fields_set__:
            _dict['replacement_role_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RemoveTeamMemberRoleRequest:
        """Create an instance of RemoveTeamMemberRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RemoveTeamMemberRoleRequest.parse_obj(obj)

        _obj = RemoveTeamMemberRoleRequest.parse_obj({
            "id": obj.get("id"),
            "replacement_role_id": obj.get("replacement_role_id")
        })
        return _obj


