# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.wrapped_response_team_member_role_response import WrappedResponseTeamMemberRoleResponse  # noqa: E501

class TestWrappedResponseTeamMemberRoleResponse(unittest.TestCase):
    """WrappedResponseTeamMemberRoleResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseTeamMemberRoleResponse:
        """Test WrappedResponseTeamMemberRoleResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseTeamMemberRoleResponse`
        """
        model = WrappedResponseTeamMemberRoleResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseTeamMemberRoleResponse(
                done = True,
                result = team_member_server_sdk.models.team_member_role_response.TeamMemberRoleResponse(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    updated_at = 56, 
                    created_at = 56, 
                    actions = [
                        ''
                        ], 
                    allowed_course_ids = [
                        56
                        ], 
                    allowed_community_ids = [
                        56
                        ], )
            )
        else:
            return WrappedResponseTeamMemberRoleResponse(
                result = team_member_server_sdk.models.team_member_role_response.TeamMemberRoleResponse(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    updated_at = 56, 
                    created_at = 56, 
                    actions = [
                        ''
                        ], 
                    allowed_course_ids = [
                        56
                        ], 
                    allowed_community_ids = [
                        56
                        ], ),
        )
        """

    def testWrappedResponseTeamMemberRoleResponse(self):
        """Test WrappedResponseTeamMemberRoleResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
