# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from team_member_server_sdk.api.team_member_role_api import TeamMemberRoleApi  # noqa: E501


class TestTeamMemberRoleApi(unittest.IsolatedAsyncioTestCase):
    """TeamMemberRoleApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TeamMemberRoleApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_team_member_role_v1_team_member_role_add_post(self) -> None:
        """Test case for add_team_member_role_v1_team_member_role_add_post

        Add Team Member role  # noqa: E501
        """
        pass

    async def test_get_team_member_roles_v1_team_member_role_list_post(self) -> None:
        """Test case for get_team_member_roles_v1_team_member_role_list_post

        Get Team Member roles  # noqa: E501
        """
        pass

    async def test_remove_team_member_role_v1_team_member_role_delete_post(self) -> None:
        """Test case for remove_team_member_role_v1_team_member_role_delete_post

        Remove Team Member role  # noqa: E501
        """
        pass

    async def test_update_team_member_role_actions_v1_team_member_role_action_update_post(self) -> None:
        """Test case for update_team_member_role_actions_v1_team_member_role_action_update_post

        Update Team Member role actions  # noqa: E501
        """
        pass

    async def test_update_team_member_role_entity_settings_v1_team_member_role_entity_settings_update_post(self) -> None:
        """Test case for update_team_member_role_entity_settings_v1_team_member_role_entity_settings_update_post

        Update Team Member role entity settings  # noqa: E501
        """
        pass

    async def test_update_team_member_role_v1_team_member_role_update_post(self) -> None:
        """Test case for update_team_member_role_v1_team_member_role_update_post

        Update Team Member role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
